@@ -1,4 +1,4 @@
-/// Make a manifest from a package name and  
+/// Make a manifest from a package name and
 /// a path to Rust Verification Tools
 ///
 /// # Examples
@@ -24,7 +24,7 @@ authors = ["Parity Technologies <admin@parity.io>", "CJDNS SASU"]
 edition = "2018"
 
 [dependencies]
-verification-annotations = { path="{{ rust_verification_tools }}/verification-annotations" }
+safepkt_assert = { git="https://github.com/LedgerProject/safepkt_assert", rev="3e8ad592df9d2138387eab43a6e37793eec66675", features = ["verifier-klee"] }
 ink_primitives = { version = "2.1.0", path = "../../primitives", default-features = false }
 ink_abi = { version = "2.1.0", path = "../../abi", default-features = false, features = ["derive"], optional = true }
 ink_core = { version = "2.1.0", path = "../../core", default-features = false }
@@ -56,7 +56,7 @@ crate-type = [
 ]
 
 [features]
-verifier-klee = ["verification-annotations/verifier-klee"]
+verifier-klee = ["safepkt_assert/verifier-klee"]
 default = ["test-env"]
 std = [
     "ink_abi/std",
@@ -92,12 +92,6 @@ members = [
 exclude = [
 	".ink"
 ]
-
-[target.'cfg(not(verify))'.dependencies]
-proptest = { version = "0.10" }
-
-[target.'cfg(verify)'.dependencies]
-propverify = { path="{{ rust_verification_tools }}/propverify" }
 "#;
 
     template
@@ -117,7 +111,7 @@ authors = ["Parity Technologies <admin@parity.io>", "CJDNS SASU"]
 edition = "2018"
 
 [dependencies]
-verification-annotations = { path="/rvt/verification-annotations" }
+safepkt_assert = { git="https://github.com/LedgerProject/safepkt_assert", rev="3e8ad592df9d2138387eab43a6e37793eec66675", features = ["verifier-klee"] }
 ink_primitives = { version = "2.1.0", path = "../../primitives", default-features = false }
 ink_abi = { version = "2.1.0", path = "../../abi", default-features = false, features = ["derive"], optional = true }
 ink_core = { version = "2.1.0", path = "../../core", default-features = false }
@@ -149,7 +143,7 @@ crate-type = [
 ]
 
 [features]
-verifier-klee = ["verification-annotations/verifier-klee"]
+verifier-klee = ["safepkt_assert/verifier-klee"]
 default = ["test-env"]
 std = [
     "ink_abi/std",
@@ -185,12 +179,6 @@ members = [
 exclude = [
 	".ink"
 ]
-
-[target.'cfg(not(verify))'.dependencies]
-proptest = { version = "0.10" }
-
-[target.'cfg(verify)'.dependencies]
-propverify = { path="/rvt/propverify" }
 "#;
 
     assert_eq!(expected_manifest, manifest::make_manifest("test", "/rvt"))
